..
    Copyright (C) 2018 CERN.
    Copyright (C) 2018 RERO.
    Invenio-Circulation is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version 1.0.0a4 (released 2019-01-26)

- Loan replace item endpoint.

Version 1.0.0a3 (released 2019-01-18)

- Creating item reference only when item pid is attached.

Version 1.0.0a2 (released 2019-01-18)

- Adding support for creating a reference inside `Loan` record to an item.

Version 1.0.0a1 (released 2018-12-04)

- Initial public release.
